import { throws } from "assert";
import axios from "axios";
import { setup } from "../config";
export class HttpService {
  url: string;
  index: string;
  constructor(url: string = "http://localhost:9200", index: string = "my-index") {
    this.url = url;
    this.index = index;
  }

  async setup(){
    try {
      const check = await this.checkIfIndexExists();
      if(!check){
        const setupNewIndex = await axios.put(`${this.url}/${this.index}`, setup);
        return setupNewIndex;
      }
      return true;
    } catch (error) {
      console.log("setup INDEX ERROR ", error);
      return false;
    }
  }

  async checkIfIndexExists(){
    try {
      const check = await axios.get(`${this.url}/${this.index}`)
      return true;
    } catch (error) {
      console.log("CHECK INDEX ERROR ", error);
      return false;
    }
  }

  async deleteIndex(){
    try {
      const del = await axios.delete(`${this.url}/${this.index}`);
    } catch (error) {
      console.log("DELETE INDEX ERROR ", error);
    }
  }

  async deleteByElasticIp(id: string) {
    try {
        const a = await axios.delete(`${this.url}/${this.index}/_doc/${id}`);
        return a.data;
    } catch (error) {
        return "Fail Delete";
    }
  }

  async addItem(obj: any, id: any = null) {
    if (id == null || id == undefined) {
      id = "";
    }
    try {
        const a = await axios.post(`${this.url}/${this.index}/_doc/${id}`, obj);
        return a.data;
    } catch (error) {
        throw new Error(error);
    }
  }
  async searchByOneOfMultiFields(
    fields: Array<string>,
    txt: any = null,
    limit:any =null,
    offset:any =null,
    ) {
    const body:any = {
      query: {
        multi_match: {
          query: txt,
          fields: fields,
        },
      },
    };
    if(offset){
      body.from = offset
    }
    if(limit){
      body.size = limit
    }
    try {
        const a = await axios.post(`${this.url}/${this.index}/_search`, body);
        return a.data.hits;
    } catch (error) {
        return "Fail Search";
    }
  }
  async updateItem(id: string, obj: any) {
    const body = {
      doc: obj,
      doc_as_upsert: true,
    };
    try {
        const a = await axios.post(`${this.url}/${this.index}/_update/${id}`, obj);
        return a.data;
    } catch (error) {
        return "Fail post update";
    }
  }
  async deleteByField(field: string, value: any) {
    const body = {
      query: {
        match: {
          [field]: value,
        },
      },
    };
    try {
        const a = await axios.post(`${this.url}/${this.index}/_delete_by_query`, body);
        return {result : "success"};
    } catch (error) {
        return "Fail Delete by query";
    }
  }
  async getByElasticId(id: string) {
    try {
        const a = await axios.get(`${this.url}/${this.index}/_doc/${id}`);
        return a.data;
    } catch (error) {
        return [];
    }
  }
  async deleteByMultipleFields(query: any) {
    const body = {
      query: {
        bool: {
          must: query,
        },
      },
    };
    try {
        const a = await axios.post(`${this.url}/${this.index}/_delete_by_query`, body);
        return { result: "success" };
    } catch (error) {
        return "Fail post update";
    }
  }
}
